@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Repository;
 
 BEGIN {
-    $Dist::Zilla::Plugin::Repository::VERSION = '0.15';
+    $Dist::Zilla::Plugin::Repository::VERSION = '0.16';
 }
 
 # ABSTRACT: Automatically sets repository URL from svn/svk/Git checkout for Dist::Zilla
@@ -18,7 +18,7 @@ has git_remote => (
 has github_http => (
     is      => 'ro',
     isa     => 'Bool',
-    default => 1,
+    default => 0,
 );
 
 has _found_repo => (
@@ -98,24 +98,26 @@ sub _find_repo {
             my $git_url = $1;
             $git_url =~ s![\w\-]+\@([^:]+):!git://$1/!;
 
+            $repo{url} = $git_url unless $git_url eq 'origin';    # RT 55136
+
             if ( $git_url =~ /^git:\/\/(github\.com.*?)\.git$/ ) {
                 $repo{web} = "http://$1";
-            }
 
-            # Changed
-            # I prefer http://github.com/fayland/dist-zilla-plugin-repository
-            #   than git://github.com/fayland/dist-zilla-plugin-repository.git
-            if (   $self->github_http
-                && $git_url =~ /^git:\/\/(github\.com.*?)\.git$/ )
-            {
-                $git_url = "http://$1";
-            }
+                if ( $self->github_http ) {
+
+                    # I prefer http://github.com/user/repository
+                    # to git://github.com/user/repository.git
+                    delete $repo{url};
+                    $self->log( "github_http is deprecated.  "
+                          . "Consider using META.json instead,\n"
+                          . "which can store URLs for both git clone "
+                          . "and the web front-end." );
+                }    # end if github_http
+            }    # end if Github repository
 
-            $repo{url} = $git_url unless $git_url eq 'origin';    # RT 55136
-            return %repo;
         }
         elsif ( $execute->('git svn info') =~ /URL: (.*)$/m ) {
-            return qw(type svn  url), $1;
+            %repo = ( qw(type svn  url), $1 );
         }
     }
     elsif ( -e ".svn" ) {
@@ -125,7 +127,7 @@ sub _find_repo {
             if ( $svn_url =~ /^https(\:\/\/.*?\.googlecode\.com\/svn\/.*)$/ ) {
                 $svn_url = 'http' . $1;
             }
-            return %repo, url => $svn_url;
+            $repo{url} = $svn_url;
         }
     }
     elsif ( -e "_darcs" ) {
@@ -145,10 +147,11 @@ sub _find_repo {
         }
     }
     elsif ( -e ".hg" ) {
+        $repo{type} = 'hg';
         if ( $execute->('hg paths') =~ /default = (.*)$/m ) {
             my $mercurial_url = $1;
             $mercurial_url =~ s!^ssh://hg\@(bitbucket\.org/)!https://$1!;
-            return qw(type hg  url) => $mercurial_url;
+            $repo{url} = $mercurial_url;
         }
     }
     elsif ( -e "$ENV{HOME}/.svk" ) {
@@ -165,9 +168,9 @@ sub _find_repo {
                 redo SVK_INFO;
             }
         }
-
-        return;
     }
+
+    return %repo;
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -185,7 +188,7 @@ Dist::Zilla::Plugin::Repository - Automatically sets repository URL from svn/svk
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
@@ -207,14 +210,19 @@ you use Git). By default, unsurprisingly, to F<origin>.
 
 =item * github_http
 
-If the remote is a GitHub repository, uses the http url
-(http://github.com/fayland/dist-zilla-plugin-repository) rather than the actual
+B<This attribute is deprecated.>
+If the remote is a GitHub repository, list only the http url
+(http://github.com/fayland/dist-zilla-plugin-repository) and not the actual
 clonable url (git://github.com/fayland/dist-zilla-plugin-repository.git).
-Defaults to true.
+This used to default to true, but as of 0.16 it defaults to false.
 
-You may want to set this to false if you're including a META.json
-file, as Meta 2 has separate keys for machine-readable C<url> and
-human-readable C<web>.  This affects only the C<url> key.
+The CPAN Meta 2 spec defines separate keys for the clonable C<url> and
+web front-end C<web>.  The Meta 1 specs allowed only 1 URL.  If you
+set C<github_http> to true, the C<url> key will be removed from the v2
+metadata, and the v1 metadata will then use the C<web> key.
+
+Instead of setting C<github_http>, you should use the MetaJSON plugin
+to include a v2 META.json file with both URLs.
 
 =item * repository
 
@@ -259,13 +267,13 @@ Moritz Onken <onken@netcubed.de>
 
 =item *
 
-Christopher J. Madsen
+Christopher J. Madsen <perl@cjmweb.net>
 
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Fayland Lam, Ricardo SIGNES, Moritz Onken.
+This software is copyright (c) 2010 by Fayland Lam, Ricardo SIGNES, Moritz Onken, Christopher J. Madsen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
